/*****		RK.H
An include header file, with Runge-Kutta routine and min(),max()
misc. routines
******/




void minmaxx(float *x,int n,float *minx,float *maxx)
{
int i;
float d1,d2;
	d1=d2=x[0];
	for(i=1;i<=n;i++){
		if (d2 < x[i])
			d2 = x[i];
		if (d1 > x[i])
			d1 = x[i];
			}
			*minx = d1;
			*maxx = d2;
}



void rk4(float y[],float dydx[],int n,float x,float h,float yout[],\
void (*f)(float,float *,float *))
/***********************************************
Given values for n variables y[1..n] and their derivatives dydx[1..n]
known at x, use the 4th order Runge-Kutta method to advance the solution
over an interval h and return the incremented variables as yout[1..n],
which need not be a distinct array from y. The user supplies the the
routine derivs(x,y,dydx) which returns derivatives dydx at x.
****************************************************************/
{
int i;
float xh,hh,h6,*dym,*dyt,*yt;
	dym= vector(n+1);
	yt= vector(n+1);
	dyt= vector(n+1);
		hh=h*0.5;
		h6=h/6.0;
		xh=x+hh;
			for(i=1;i<=n;i++)
			   yt[i]= y[i] + hh*dydx[i];  /* First Step */
			     (*f)(xh,yt,dyt);    /* Second step */

			for(i=1;i<=n;i++)
			   yt[i]= y[i] + hh*dyt[i];
			     (*f)(xh,yt,dym);    /* Third step */
			for(i=1;i<=n;i++){
			   yt[i]= y[i] + h*dym[i];
			   dym[i] += dyt[i];
					}
			     (*f)(x+h,yt,dyt);    /* Fourth step */
		for(i=1;i<=n;i++)
		yout[i]=y[i]+h6*(dydx[i]+dyt[i]+2.0*dym[i]);
			free_vector(yt);
			free_vector(dyt);
			free_vector(dym);
}

















